<?php
require 'config.php';
require '2021-07-07-why-income-inequality-is-not-directly-important.cfg.php';
require 'templates/blog-header.php';
?>
<p>Originally I had planned to make the title of this post "Why Income
Inequality is not Important", but I realized that this could be
misleading as to what I'm actually trying to express. Although I'm
unsure that the title I have chosen will be much different.</p>

<p>When talking about economics in a country, income inequality seems to
come up quite often, especially among those who are more left-leaning on
economic issues. It's generally hard to argue the position that it is
good for a country to have more income inequality - which is not to say
there aren't people who may try to defend this position - and in fact
it's quite normally described as being a bad thing, being representative
of an unjust society. However, this is not the focus of this post.
Instead, I'd like to focus on whether income inequality is a useful form
of measuring the <em>well-being</em> of the people in a country.</p>

<p>According to the OECD, income inequality is "an indicator of how
material resources are distributed across a
society."<sup><a href="#r1" >[1]</a></sup> As such, we can say it is an
indication of the difference of access to material resources from the
most to the least wealthy. However this definition has a flaw in it if
what we're trying to look for is well-being, and not simply difference
in income.</p>

<p>With this I'm not trying to deny that there is indeed a correlation
between income inequality and median income. In the following graph I
plot out over a dozen countries according to their median disposable
income and the Gini Coefficient.</p>

<figure>
	<img
		src="https://media.themusicinnoise.net/imgs/blog/income-inequality-vs-median-income.png"
		title="Income Inequality vs. Median Income"
		alt="Income Inequality vs. Median Income Graph" />
	<figcaption>
		Sources: "List of Countries by Income Equality" and
		"Disposable Household and per Capita Income" from
		Wikipedia<sup><a href="#r2" >[2]</a></sup><sup><a href="#r3" >[3]</a></sup>
	</figcaption>
</figure>

<p>From this graph, there is a clear correlation between income
inequality and median income. Although there may be a few outliers, that
is the general trend. Yet if we're caring about the well-being of human
persons, then why would we use an indicator that does not directly
measure this? If we care about the well-being of all people in a country
then we shouldn't be looking at income inequality, or even median
income, we should be looking at the lowest income household in every
country. Reason being, we care about the human person, and while income
inequality may be correlated to the median income, it is better to have
a society with a large income inequality but where the poorest household
can afford to live a dignified life, than a small income inequality but
where the poorest household (and likely most households) are unable to
live dignified lives. In other words, we should be looking at a more
direct measurement of the well-being of the members of a society who are
worst off, and assure their dignified living.</p>

<p>The problem with focusing too much on income inequality is it can end
up turning into envy: we envy what the rich have and wish to either
bring them down, or for everyone to have what they have - regardless of
how unsustainable that may be. It leads to a lack of contentment with
what God has given us, and rather than focusing on the poorest members
of society, we turn ourselves into victims and believe the solution is
by bringing down those who are more well-off. Which is not to say that
some assets will not require redistribution, but the intention of that
redistribution should not be a sense of envy or hatred towards those who
have, but rather to simply provide the poorest members of our society
with a means to sustain themselves and live dignified lives.</p>

<p>To put this in a different manner, would it really matter if there
were a few really rich people, but every man still had a dignified job
such that he could sustain himself and his family? The anger and
unhappiness that manifests itself in this hatred of the rich seems to
simply be out of envy. But rather than advocating, like many of the
Libertarian persuasion would, that everyone should find their own way to
being rich, my line of arguing is to look at what we already have and be
content with it. Why do we need riches? Ultimately they will not bring
us joy, and may even risk our eternal happiness if we get too attached.
Our Lord Himself said that "It is easier for a camel to go through the
eye of a needle, than for a rich man to enter into the kingdom of God"
(Matt. 19:24). But to envy the rich is perhaps worse, as it stimulates a
hatred of others, which is sinful by nature.</p>

<p>Therefore, let's take care as to use the data that best represents
what we're actually trying to argue, and make sure that we're trying to
fix the right thing.</p>

<ol class="refs" >
	<li id="r1" >
		<a href="https://www.oecd.org/berlin/47570121.pdf"
		   target="_blank" >
			Society at a Glance 2011: OECD Social Indicators
		</a>
	</li>
	<li id="r2" >
		<a href="https://en.wikipedia.org/wiki/List_of_countries_by_income_equality"
		   target="_blank" >
		    List of Countries by Income Equality - Wikipedia
		</a>
	</li>
	<li id="r3" >
		<a href="https://en.wikipedia.org/wiki/Disposable_household_and_per_capita_income#Median"
		   target="_blank" >
			Disposable household and per capita income - Wikipedia
		</a>
	</li>
</ol>

<?php
require 'templates/blog-footer.php';
?>